summaryrefslogtreecommitdiff
path: root/repackaged/libphonenumber/src/com/android/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
diff options
context:
space:
mode:
Diffstat (limited to 'repackaged/libphonenumber/src/com/android/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java')
-rw-r--r--repackaged/libphonenumber/src/com/android/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java5
1 files changed, 2 insertions, 3 deletions
diff --git a/repackaged/libphonenumber/src/com/android/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java b/repackaged/libphonenumber/src/com/android/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
index 5432f670..cca8a0b8 100644
--- a/repackaged/libphonenumber/src/com/android/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
+++ b/repackaged/libphonenumber/src/com/android/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
@@ -30,9 +30,9 @@ import java.util.Set;
public class AlternateFormatsCountryCodeSet {
// A set of all country codes for which data is available.
static Set<Integer> getCountryCodeSet() {
// The capacity is set to 62 as there are 47 different entries,
// and this offers a load factor of roughly 0.75.
- Set<Integer> countryCodeSet = new HashSet<Integer>(62);
+ Set<Integer> countryCodeSet = new HashSet<Integer>(61);
countryCodeSet.add(7);
countryCodeSet.add(27);
@@ -50,7 +50,6 @@ public class AlternateFormatsCountryCodeSet {
countryCodeSet.add(58);
countryCodeSet.add(61);
countryCodeSet.add(62);
- countryCodeSet.add(63);
countryCodeSet.add(64);
countryCodeSet.add(66);
countryCodeSet.add(81);
@@ -30,9 +30,9 @@ import java.util.Set;
// A set of all country codes for which data is available.
static Set<Integer> getCountryCodeSet() {
- // The capacity is set to 62 as there are 47 different entries,
+ // The capacity is set to 61 as there are 46 different entries,
// and this offers a load factor of roughly 0.75.